@@ -53,6 +53,20 @@ is.edgeList <- function(x){
     inherits(x, "edgeList")
 } # END IS.EDGELIST
 
+#' as.edgeList
+#'
+#' Methods for coercing other \code{R} objects to \code{\link{edgeList}} objects.
+#'
+#' @param x A compatible \code{R} object.
+#'
+#' @return
+#' \code{\link{edgeList}}
+#'
+#' @export
+as.edgeList <- function(x){
+    edgeList(x) # NOTE: S3 delegation is implicitly handled by the constructor here
+}
+
 #' @export
 edgeList.list <- function(x){
     if(!is.list(x)){
@@ -92,6 +106,35 @@ edgeList.list <- function(x){
     structure(x, class = c("edgeList", "list"))
 } # END EDGELIST.LIST
 
+#' @export
+edgeList.sparse <- function(x, ...){
+    stopifnot(x$dim[1] == x$dim[2])
+
+    out <- lapply(vector("list", length = x$dim[1]), as.integer) # need as.integer to convert NULLs into integer(0)
+    for(j in seq_along(x$cols)){
+        child <- x$cols[[j]]
+        parent <- x$rows[[j]]
+        out[[child]] <- c(out[[child]], parent) # !!! THIS IS SLOW
+    }
+
+    edgeList(out)
+}
+
+#' @export
+edgeList.matrix <- function(x){
+    out <- edgeList(as.sparse(x))
+
+    if(!all(colnames(x) == rownames(x))){
+        warning("Row names do not match column names! Defaulting to use column names only.")
+    }
+
+    if(!is.null(colnames(x))){
+        names(out) <- colnames(x)
+    }
+
+    out
+}
+
 #' @method print edgeList
 #' @export
 print.edgeList <- function(x, maxsize = 20, ...){
@@ -135,6 +178,10 @@ get.adjacency.matrix.edgeList <- function(x){
     numnode <- length(x)
     Matrix.out <- Matrix::Matrix(0, nrow = numnode, ncol = numnode)
 
+    ### Set column and row names for output
+    node_names <- names(x)
+    colnames(Matrix.out) <- rownames(Matrix.out) <- node_names
+
     ### This loop is pretty slow!
     for(j in seq_along(x)){
         for(i in x[[j]]){
